Class {
	#name : #PPCommonMarkSpecTest,
	#superclass : #PPCompositeParserTest,
	#instVars : [
		'expected',
		'input',
		'ast',
		'blockParser',
		'blockAst',
		'blockVisitor',
		'htmlVisitor'
	],
	#category : #'PetitMarkdown-Tests'
}

{ #category : #'as yet unclassified' }
PPCommonMarkSpecTest >> assertExample [
	|  |
	"Create block structure"
	blockAst := blockParser parse: input.
	
	"Parse inlines of block"
	ast := blockAst accept: blockVisitor.

	"Generate HTML"
	result := ast accept: htmlVisitor.
	self assert: expected = result.
	
	"
	(TextDiffBuilder from: expected to: result) buildDisplayPatch.
	"
	
	
]

{ #category : #'as yet unclassified' }
PPCommonMarkSpecTest >> setUp [
	blockVisitor := CMBlockVisitor new.
	htmlVisitor := CMHTMLVisitor new.
	blockParser := PPCommonMarkBlockParser new.
]

{ #category : #'tab expansion' }
PPCommonMarkSpecTest >> testExample001 [
	input := String tab, 'foo', String tab, 'baz', String tab, String tab, 'bim'.
	expected := '<pre><code>foo baz     bim
</code></pre>'.

	true ifTrue: [ ^ self flag: 'tabstops not yet supported' ].
	self assertExample.
]

{ #category : #'tab expansion' }
PPCommonMarkSpecTest >> testExample002 [
	input := 'a', String tab, 'a', String cr, '    ὐ', String tab, 'a'.
	expected := '<pre><code>a   a
ὐ   a
</code></pre>'.

	true ifTrue: [ ^ self flag: 'tabstops not yet supported' ].
	self assertExample.
]

{ #category : #precedence }
PPCommonMarkSpecTest >> testExample003 [
	input := '- `one
- two`'.
	expected := '<ul>
<li>`one</li>
<li>two`</li>
</ul>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample004 [
	input := '***
---
___'.
	expected := '<hr />
<hr />
<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample004a [
	input := '***'.
	expected := '<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample005 [
	input := '+++'.
	expected := '<p>+++</p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample006 [
	input := '==='.
	expected := '<p>===</p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample007 [
	input := '--
**
__'.
	expected := '<p>--
**
__</p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample008 [
	input := ' ***
  ***
   ***
'.
	expected := '<hr />
<hr />
<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample009 [
	input := '    ***'.
	expected := '<pre><code>***
</code></pre>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample010 [
	input := 'Foo
    ***'.
	expected := '<p>Foo
***</p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample011 [
	input := '_____________________________________'.
	expected := '<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample012 [
	input := ' - - -'.
	expected := '<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample013 [
	input := ' **  * ** * ** * **'.
	expected := '<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample014 [
	input := '-     -      -      -'.
	expected := '<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample015 [
	input := '- - - -    '.
	expected := '<hr />'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample016 [
	input := '_ _ _ _ a

a------

---a---
'.
	expected := '<p>_ _ _ _ a</p>
<p>a------</p>
<p>---a---</p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample017 [
	input := ' *-*'.
	expected := '<em>-</em>'.

	self flag: 'updated:'.
	expected := '<p><em>-</em></p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample018 [
	input := '- foo
***
- bar'.
	expected := '<ul>
<li>foo</li>
</ul>
<hr />
<ul>
<li>bar</li>
</ul>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample019 [
	input := 'Foo
***
bar'.
	expected := '<p>Foo</p>
<hr />
<p>bar</p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample020 [
	input := 'Foo
---
bar'.
	expected := '<h2>Foo</h2>
<p>bar</p>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample021 [
	input := '* Foo
* * *
* Bar'.

	expected := '<ul>
<li>Foo</li>
</ul>
<hr />
<ul>
<li>Bar</li>
</ul>'.

	self assertExample.
]

{ #category : #'horizontal rules' }
PPCommonMarkSpecTest >> testExample022 [
	input := '- Foo
- * * *'.

	expected := '<ul>
<li>Foo</li>
<li>
<hr />
</li>
</ul>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample023 [
	input := '# foo
## foo
### foo
#### foo
##### foo
###### foo'.

	expected := '<h1>foo</h1>
<h2>foo</h2>
<h3>foo</h3>
<h4>foo</h4>
<h5>foo</h5>
<h6>foo</h6>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample024 [
	input := '####### foo'.

	expected := '<p>####### foo</p>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample025 [
	input := '#5 bolt'.

	expected := '<p>#5 bolt</p>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample026 [
	input := '\## foo'.

	expected := '<p>## foo</p>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample027 [
	input := '# foo *bar* \*baz\*'.

	expected := '<h1>foo <em>bar</em> *baz*</h1>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample028 [
	input := '#                  foo                    '.

	expected := '<h1>foo</h1>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample029 [
	input := ' ### foo
  ## foo
   # foo'.

	expected := '<h3>foo</h3>
<h2>foo</h2>
<h1>foo</h1>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample030 [
	input := '    # foo'.

	expected := '<pre><code># foo
</code></pre>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample031 [
	input := 'foo
    # bar'.

	expected := '<p>foo
# bar</p>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample032 [
	input := '## foo ##
  ###   bar    ###'.

	expected := '<h2>foo</h2>
<h3>bar</h3>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample033 [
	input := '# foo ##################################
##### foo ##'.

	expected := '<h1>foo</h1>
<h5>foo</h5>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample034 [
	input := '### foo ###     '.

	expected := '<h3>foo</h3>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample035 [
	input := '### foo ### b'.

	expected := '<h3>foo ### b</h3>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample036 [
	input := '# foo#'.

	expected := '<h1>foo#</h1>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample037 [
	input := '### foo \###
## foo #\##
# foo \#'.

	expected := '<h3>foo ###</h3>
<h2>foo ###</h2>
<h1>foo #</h1>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample038 [
	input := '****
## foo
****'.

	expected := '<hr />
<h2>foo</h2>
<hr />'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample039 [
	input := 'Foo bar
# baz
Bar foo'.

	expected := '<p>Foo bar</p>
<h1>baz</h1>
<p>Bar foo</p>'.

	self assertExample.
]

{ #category : #'ATX Headers' }
PPCommonMarkSpecTest >> testExample040 [
	input := '## 
#
### ###'.

	expected := '<h2></h2>
<h1></h1>
<h3></h3>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample041 [
	input := 'Foo *bar*
=========

Foo *bar*
---------'.

	expected := '<h1>Foo <em>bar</em></h1>
<h2>Foo <em>bar</em></h2>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample042 [
	input := 'Foo
-------------------------

Foo
='.

	expected := '<h2>Foo</h2>
<h1>Foo</h1>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample043 [
	input := '   Foo
---

  Foo
-----

  Foo
  ==='.

	expected := '<h2>Foo</h2>
<h2>Foo</h2>
<h1>Foo</h1>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample044 [
	input := '    Foo
    ---

    Foo
---'.

	expected := '<pre><code>Foo
---

Foo
</code></pre>
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample045 [
	input := 'Foo
   ----      '.

	expected := '<h2>Foo</h2>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample046 [
	input := 'Foo
    ---'.

	expected := '<p>Foo
---</p>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample047 [
	input := 'Foo
= =

Foo
--- -
'.

	expected := '<p>Foo
= =</p>
<p>Foo</p>
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample048 [
	input := 'Foo  
-----'.

	expected := '<h2>Foo</h2>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample049 [
	input := 'Foo\
----'.

	expected := '<h2>Foo\</h2>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample050 [
	input := '`Foo
----
`

<a title="a lot
---
of dashes"/>'.

	expected := '<h2>`Foo</h2>
<p>`</p>
<h2>&lt;a title=&quot;a lot</h2>
<p>of dashes&quot;/&gt;</p>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample051 [
	input := '> Foo
---'.

	expected := '<blockquote>
<p>Foo</p>
</blockquote>
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample052 [
	input := '- Foo
---'.

	expected := '<ul>
<li>Foo</li>
</ul>
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample053 [
	input := 'Foo
Bar
---

Foo
Bar
==='.

	expected := '<p>Foo
Bar</p>
<hr />
<p>Foo
Bar
===</p>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample054 [
	input := '---
Foo
---
Bar
---
Baz'.

	expected := '<hr />
<h2>Foo</h2>
<h2>Bar</h2>
<p>Baz</p>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample055 [
	input := '
===='.

	expected := '<p>====</p>'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample056 [
	input := '---
---'.

	expected := '<hr />
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample057 [
	input := '- foo
-----'.

	expected := '<ul>
<li>foo</li>
</ul>
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample058 [
	input := '    foo
---'.

	expected := '<pre><code>foo
</code></pre>
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample059 [
	input := '> foo
-----'.

	expected := '<blockquote>
<p>foo</p>
</blockquote>
<hr />'.

	self assertExample.
]

{ #category : #'setext headears' }
PPCommonMarkSpecTest >> testExample060 [
	input := '\> foo
------'.

	expected := '<h2>&gt; foo</h2>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample061 [
	input := '    a simple
      indented code block'.

	expected := '<pre><code>a simple
  indented code block
</code></pre>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample062 [
	input := '    <a/>
    *hi*

    - one'.

	expected := '<pre><code>&lt;a/&gt;
*hi*

- one
</code></pre>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample063 [
	input := '    chunk1

    chunk2
  
 
 
    chunk3'.

	expected := '<pre><code>chunk1

chunk2



chunk3
</code></pre>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample064 [
	input := '    chunk1
      
      chunk2'.

	expected := '<pre><code>chunk1
  
  chunk2
</code></pre>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample065 [
	input := 'Foo
    bar'.

	expected := '<p>Foo
bar</p>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample066 [
	input := '    foo
bar'.

	expected := '<pre><code>foo
</code></pre>
<p>bar</p>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample067 [
	input := '# Header
    foo
Header
------
    foo
----'.

	expected := '<h1>Header</h1>
<pre><code>foo
</code></pre>
<h2>Header</h2>
<pre><code>foo
</code></pre>
<hr />'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample068 [
	input := '        foo
    bar'.

	expected := '<pre><code>    foo
bar
</code></pre>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample069 [
	input := '
    
    foo
    '.

	expected := '<pre><code>foo
</code></pre>'.

	self assertExample.
]

{ #category : #'indented code blocks' }
PPCommonMarkSpecTest >> testExample070 [
	input := '    foo  
'.

	expected := '<pre><code>foo  
</code></pre>'.

	self assertExample.
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample071 [
	input := '```
<
 >
```'.

	expected := '<pre><code>&lt;
 &gt;
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample072 [
	input := '~~~
<
 >
~~~'.

	expected := '<pre><code>&lt;
 &gt;
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample073 [
	input := '```
aaa
~~~
```'.

	expected := '<pre><code>aaa
~~~
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample074 [
	input := '~~~
aaa
```
~~~'.

	expected := '<pre><code>aaa
```
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample075 [
	input := '````
aaa
```
``````'.

	expected := '<pre><code>aaa
```
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample076 [
	input := '~~~~
aaa
~~~
~~~~'.

	expected := '<pre><code>aaa
~~~
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample077 [
	input := '```'.

	expected := '<pre><code></code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample078 [
	input := '

`````

```
aaa
'.

	expected := '<pre><code>
```
aaa
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample079 [
	input := '```

  
```
'.

	expected := '<pre><code>
  
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample080 [
	input := '```
```'.

	expected := '<pre><code></code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample081 [
	input := ' ```
 aaa
aaa
```'.

	expected := '<pre><code>aaa
aaa
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample082 [
	input := '  ```
aaa
  aaa
aaa
  ```'.

	expected := '<pre><code>aaa
aaa
aaa
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample083 [
	input := '   ```
   aaa
    aaa
  aaa
   ```'.

	expected := '<pre><code>aaa
 aaa
aaa
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample084 [
	input := '    ```
    aaa
    ```'.

	expected := '<pre><code>```
aaa
```
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample085 [
	input := '```
aaa
  ```'.

	expected := '<pre><code>aaa
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample086 [
	input := '   ```
aaa
  ```'.

	expected := '<pre><code>aaa
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample087 [
	input := '```
aaa
    ```'.

	expected := '<pre><code>aaa
    ```
</code></pre>'.

	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample088 [
	input := '``` ```
aaa'.

	expected := '<p><code></code>
aaa</p>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample089 [
	input := '~~~~~~
aaa
~~~ ~~'.

	expected := '<pre><code>aaa
~~~ ~~
</code></pre>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample090 [
	input := 'foo
```
bar
```
baz'.

	expected := '<p>foo</p>
<pre><code>bar
</code></pre>
<p>baz</p>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample091 [
	input := 'foo
---
~~~
bar
~~~
# baz'.

	expected := '<h2>foo</h2>
<pre><code>bar
</code></pre>
<h1>baz</h1>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample092 [
	input := '```ruby
def foo(x)
  return 3
end
```'.

	expected := '<pre><code class="language-ruby">def foo(x)
  return 3
end
</code></pre>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample093 [
	input := '~~~~    ruby startline=3 $%@#$
def foo(x)
  return 3
end
~~~~~~~'.

	expected := '<pre><code class="language-ruby">def foo(x)
  return 3
end
</code></pre>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample094 [
	input := '````;
````'.

	expected := '<pre><code class="language-;"></code></pre>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample095 [
	input := '``` aa ```
foo'.

	expected := '<p><code>aa</code>
foo</p>'.
	
	self assertExample. 
]

{ #category : #'fenced code blocks' }
PPCommonMarkSpecTest >> testExample096 [
	input := '```
``` aaa
```'.

	expected := '<pre><code>``` aaa
</code></pre>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample097 [
	input := '<table>
  <tr>
    <td>
           hi
    </td>
  </tr>
</table>

okay.'.

	expected := '<table>
  <tr>
    <td>
           hi
    </td>
  </tr>
</table>
<p>okay.</p>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample098 [
	input := ' <div>
  *hello*
         <foo><a>
'.

	expected := ' <div>
  *hello*
         <foo><a>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample099 [
	input := '<DIV CLASS="foo">

*Markdown*

</DIV>'.

	expected := '<DIV CLASS="foo">
<p><em>Markdown</em></p>
</DIV>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample100 [
	input := '<div></div>
``` c
int x = 33;
```'.

	expected := '<div></div>
``` c
int x = 33;
```'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample101 [
	input := '<!-- Foo
bar
   baz -->'.

	expected := '<!-- Foo
bar
   baz -->'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample102 [
	input := '<?php
  echo ''>'';
?>'.

	expected := '<?php
  echo ''>'';
?>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample103 [
	input := '<![CDATA[
function matchwo(a,b)
{
if (a < b && a < 0) then
  {
  return 1;
  }
else
  {
  return 0;
  }
}
]]>'.

	expected := '<![CDATA[
function matchwo(a,b)
{
if (a < b && a < 0) then
  {
  return 1;
  }
else
  {
  return 0;
  }
}
]]>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample104 [
	input := '  <!-- foo -->

    <!-- foo -->'.

	expected := '  <!-- foo -->
<pre><code>&lt;!-- foo --&gt;
</code></pre>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample105 [
	input := 'Foo
<div>
bar
</div>'.

	expected := '<p>Foo</p>
<div>
bar
</div>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample106 [
	input := '<div>
bar
</div>
*foo*'.

	expected := '<div>
bar
</div>
*foo*'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample107 [
	input := '<div class
foo'.

	expected := '<div class
foo'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample108 [
	input := '<div>

*Emphasized* text.

</div>'.

	expected := '<div>
<p><em>Emphasized</em> text.</p>
</div>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample109 [
	input := '<div>
*Emphasized* text.
</div>'.

	expected := '<div>
*Emphasized* text.
</div>'.
	
	self assertExample. 
]

{ #category : #'html blocks' }
PPCommonMarkSpecTest >> testExample110 [
	input := '<table>

<tr>

<td>
Hi
</td>

</tr>

</table>'.

	expected := '<table>
<tr>
<td>
Hi
</td>
</tr>
</table>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample111 [
	input := '[foo]: /url "title"

[foo]'.

	expected := '<p><a href="/url" title="title">foo</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample112 [
	input := '   [foo]: 
      /url  
           ''the title''  

[foo]'.

	expected := '<p><a href="/url" title="the title">foo</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample113 [
	input := '[Foo*bar\]]:my_(url) ''title (with parens)''

[Foo*bar\]]'.

	expected := '<p><a href="my_(url)" title="title (with parens)">Foo*bar]</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample114 [
	input := '[Foo bar]:
<my url>
''title''

[Foo bar]'.

	expected := '<p><a href="my%20url" title="title">Foo bar</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample115 [
	input := '[foo]: /url ''
title
line1
line2
''

[foo]'.

	expected := '<p><a href="/url" title="
title
line1
line2
">foo</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample116 [
	input := '[foo]: /url ''title

with blank line''

[foo]'.

	expected := '<p>[foo]: /url ''title</p>
<p>with blank line''</p>
<p>[foo]</p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample117 [
	input := '[foo]:
/url

[foo]'.

	expected := '<p><a href="/url">foo</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample118 [
	input := '[foo]:

[foo]'.

	expected := '<p>[foo]:</p>
<p>[foo]</p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample119 [
	input := '[foo]

[foo]: url'.

	expected := '[foo]

[foo]: url'.
	
	true ifTrue: [ ^ self flag: 'links before definitions not yet supported' ].
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample120 [
	input := '[foo]: first
[foo]: second

[foo]'.

	expected := '<p><a href="first">foo</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample121 [
	input := '[FOO]: /url

[Foo]'.

	expected := '<p><a href="/url">Foo</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample122 [
	input := '[ΑΓΩ]: /φου

[αγω]'.

	expected := '<p><a href="/%CF%86%CE%BF%CF%85">αγω</a></p>'.
	true ifTrue: [ ^ self flag: 'escaping not yet supported...' ].
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample122a [
	input := '[ΑΓΩ]: /foo

[αγω]'.

	expected := '<p><a href="/foo">αγω</a></p>'.
	
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample123 [
	input := '[foo]: /url'.

	expected := ''.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample124 [
	input := '[
foo
]: /url
bar'.

	expected := '<p>bar</p>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample125 [
	input := '[foo]: /url "title" ok'.

	expected := '<p>[foo]: /url &quot;title&quot; ok</p>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample126 [
	input := '    [foo]: /url "title"

[foo]'.

	expected := '<pre><code>[foo]: /url &quot;title&quot;
</code></pre>
<p>[foo]</p>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample127 [
	input := '```
[foo]: /url
```

[foo]
'.

	expected := '<pre><code>[foo]: /url
</code></pre>
<p>[foo]</p>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample128 [
	input := 'Foo
[bar]: /baz

[bar]'.

	expected := '<p>Foo
[bar]: /baz</p>
<p>[bar]</p>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample129 [
	input := '# [Foo]
[foo]: /url
> bar'.

	expected := '<h1><a href="/url">Foo</a></h1>
<blockquote>
<p>bar</p>
</blockquote>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample129a [
	input := '[foo]: /url
# [Foo]
> bar'.

	expected := '<h1><a href="/url">Foo</a></h1>
<blockquote>
<p>bar</p>
</blockquote>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample130 [
	input := '[foo]: /foo-url "foo"
[bar]: /bar-url
  "bar"
[baz]: /baz-url

[foo],
[bar],
[baz]'.

	expected := '<p><a href="/foo-url" title="foo">foo</a>,
<a href="/bar-url" title="bar">bar</a>,
<a href="/baz-url">baz</a></p>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample131 [
	input := '[foo]

> [foo]: /url'.

	expected := '<p><a href="/url">foo</a></p>
<blockquote>
</blockquote>'.
	self assertExample. 
]

{ #category : #'link references' }
PPCommonMarkSpecTest >> testExample131a [
	input := '> [foo]: /url
[foo]'.

	expected := '<blockquote>
</blockquote>
<p><a href="/url">foo</a></p>'.
	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample132 [
	input := 'aaa

bbb'.

	expected := '<p>aaa</p>
<p>bbb</p>'.
	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample133 [
	input := 'aaa
bbb

ccc
ddd'.

	expected := '<p>aaa
bbb</p>
<p>ccc
ddd</p>'.
	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample134 [
	input := 'aaa


bbb'.

	expected := '<p>aaa</p>
<p>bbb</p>'.
	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample135 [
	input := '  aaa
 bbb'.

	expected := '<p>aaa
bbb</p>'.
	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample136 [
	input := 'aaa
             bbb
                                       ccc'.

	expected := '<p>aaa
bbb
ccc</p>'.
	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample137 [
	input := '   aaa
bbb'.

	expected := '<p>aaa
bbb</p>'.
	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample138 [
	input := '    aaa
bbb'.

	expected := '<pre><code>aaa
</code></pre>
<p>bbb</p>'.

	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testExample139 [
	input := 'aaa     
bbb     '.

	expected := '<p>aaa<br />
bbb</p>'.

	self assertExample. 
]

{ #category : #'blank lines' }
PPCommonMarkSpecTest >> testExample140 [
	input := '  

aaa
  

# aaa

  
'.

	expected := '<p>aaa</p>
<h1>aaa</h1>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample141 [
	input := '> # Foo
> bar
> baz'.

	expected := '<blockquote>
<h1>Foo</h1>
<p>bar
baz</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample142 [
	input := '># Foo
>bar
> baz'.

	expected := '<blockquote>
<h1>Foo</h1>
<p>bar
baz</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample143 [
	input := '   > # Foo
   > bar
 > baz'.

	expected := '<blockquote>
<h1>Foo</h1>
<p>bar
baz</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample144 [
	input := '    > # Foo
    > bar
    > baz'.

	expected := '<pre><code>&gt; # Foo
&gt; bar
&gt; baz
</code></pre>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample145 [
	input := '> # Foo
> bar
baz'.

	expected := '<blockquote>
<h1>Foo</h1>
<p>bar
baz</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample146 [
	input := '> bar
baz
> foo'.

	expected := '<blockquote>
<p>bar
baz
foo</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample147 [
	input := '> foo
---'.

	expected := '<blockquote>
<p>foo</p>
</blockquote>
<hr />'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample148 [
	input := '> - foo
- bar'.

	expected := '<blockquote>
<ul>
<li>foo</li>
</ul>
</blockquote>
<ul>
<li>bar</li>
</ul>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample149 [
	input := '>     foo
    bar'.

	expected := '<blockquote>
<pre><code>foo
</code></pre>
</blockquote>
<pre><code>bar
</code></pre>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample150 [
	input := '> ```
foo
```'.

	expected := '<blockquote>
<pre><code></code></pre>
</blockquote>
<p>foo</p>
<pre><code></code></pre>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample151 [
	input := '>'.

	expected := '<blockquote>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample152 [
	input := '>
>  
> '.

	expected := '<blockquote>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample153 [
	input := '>
> foo
>  '.

	expected := '<blockquote>
<p>foo</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample154 [
	input := '> foo

> bar'.

	expected := '<blockquote>
<p>foo</p>
</blockquote>
<blockquote>
<p>bar</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample155 [
	input := '> foo
> bar'.

	expected := '<blockquote>
<p>foo
bar</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample156 [
	input := '> foo
>
> bar'.

	expected := '<blockquote>
<p>foo</p>
<p>bar</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample157 [
	input := 'foo
> bar'.

	expected := '<p>foo</p>
<blockquote>
<p>bar</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample158 [
	input := '> aaa
***
> bbb'.

	expected := '<blockquote>
<p>aaa</p>
</blockquote>
<hr />
<blockquote>
<p>bbb</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample159 [
	input := '> bar
baz'.

	expected := '<blockquote>
<p>bar
baz</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample160 [
	input := '> bar

baz'.

	expected := '<blockquote>
<p>bar</p>
</blockquote>
<p>baz</p>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample161 [
	input := '> bar
>
baz'.

	expected := '<blockquote>
<p>bar</p>
</blockquote>
<p>baz</p>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample162 [
	input := '> > > foo
bar'.

	expected := '<blockquote>
<blockquote>
<blockquote>
<p>foo
bar</p>
</blockquote>
</blockquote>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample163 [
	input := '>>> foo
> bar
>>baz'.

	expected := '<blockquote>
<blockquote>
<blockquote>
<p>foo
bar
baz</p>
</blockquote>
</blockquote>
</blockquote>'.

	self assertExample. 
]

{ #category : #'block quotes' }
PPCommonMarkSpecTest >> testExample164 [
	input := '>     code

>    not code'.

	expected := '<blockquote>
<pre><code>code
</code></pre>
</blockquote>
<blockquote>
<p>not code</p>
</blockquote>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample165 [
	input := 'A paragraph
with two lines.

    indented code

> A block quote.'.

	expected := '<p>A paragraph
with two lines.</p>
<pre><code>indented code
</code></pre>
<blockquote>
<p>A block quote.</p>
</blockquote>'.
	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample166 [
	input := '1.  A paragraph
    with two lines.

        indented code

    > A block quote.'.

	expected := '<ol>
<li>
<p>A paragraph
with two lines.</p>
<pre><code>indented code
</code></pre>
<blockquote>
<p>A block quote.</p>
</blockquote>
</li>
</ol>'.
	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample167 [
	input := '- one

 two'.

	expected := '<ul>
<li>one</li>
</ul>
<p>two</p>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample168 [
	input := '- one

  two'.

	expected := '<ul>
<li>
<p>one</p>
<p>two</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample169 [
	input := ' -    one

     two'.

	expected := '<ul>
<li>one</li>
</ul>
<pre><code> two
</code></pre>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample170 [
	input := ' -    one

      two'.

	expected := '<ul>
<li>
<p>one</p>
<p>two</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample171 [
	input := '   > > 1.  one
>>
>>     two'.

	expected := '<blockquote>
<blockquote>
<ol>
<li>
<p>one</p>
<p>two</p>
</li>
</ol>
</blockquote>
</blockquote>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample172 [
	input := '>>- one
>>
  >  > two'.

	expected := '<blockquote>
<blockquote>
<ul>
<li>one</li>
</ul>
<p>two</p>
</blockquote>
</blockquote>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample173 [
	input := '-one

2.two'.

	expected := '<p>-one</p>
<p>2.two</p>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample174 [
	input := '- foo

  bar

- foo


  bar

- ```
  foo


  bar
  ```

- baz

  + ```
    foo


    bar
    ```'.

	expected := '<ul>
<li>
<p>foo</p>
<p>bar</p>
</li>
<li>
<p>foo</p>
</li>
</ul>
<p>bar</p>
<ul>
<li>
<pre><code>foo


bar
</code></pre>
</li>
<li>
<p>baz</p>
<ul>
<li>
<pre><code>foo


bar
</code></pre>
</li>
</ul>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample175 [
	input := '1.  foo

    ```
    bar
    ```

    baz

    > bam'.

	expected := '<ol>
<li>
<p>foo</p>
<pre><code>bar
</code></pre>
<p>baz</p>
<blockquote>
<p>bam</p>
</blockquote>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample176 [
	input := '- foo

      bar'.

	expected := '<ul>
<li>
<p>foo</p>
<pre><code>bar
</code></pre>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample177 [
	input := '

  10.  foo

           bar'.

	expected := '<ol start="10">
<li>
<p>foo</p>
<pre><code>bar
</code></pre>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample178 [
	input := '    indented code

paragraph

    more code'.

	expected := '<pre><code>indented code
</code></pre>
<p>paragraph</p>
<pre><code>more code
</code></pre>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample179 [
	input := '1.     indented code

   paragraph

       more code'.

	expected := '<ol>
<li>
<pre><code>indented code
</code></pre>
<p>paragraph</p>
<pre><code>more code
</code></pre>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample180 [
	input := '1.      indented code

   paragraph

       more code'.

	expected := '<ol>
<li>
<pre><code> indented code
</code></pre>
<p>paragraph</p>
<pre><code>more code
</code></pre>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample181 [
	input := '   foo

bar'.

	expected := '<p>foo</p>
<p>bar</p>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample182 [
	input := '-    foo

  bar'.

	expected := '<ul>
<li>foo</li>
</ul>
<p>bar</p>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample183 [
	input := '-  foo

   bar'.

	expected := '<ul>
<li>
<p>foo</p>
<p>bar</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample184 [
	input := '-
  foo
-
  ```
  bar
  ```
-
      baz'.

	expected := '<ul>
<li>foo</li>
<li>
<pre><code>bar
</code></pre>
</li>
<li>
<pre><code>baz
</code></pre>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample185 [
	input := '- foo
-
- bar'.

	expected := '<ul>
<li>foo</li>
<li></li>
<li>bar</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample186 [
	input := '- foo
-   
- bar'.

	expected := '<ul>
<li>foo</li>
<li></li>
<li>bar</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample187 [
	input := '1. foo
2.
3. bar'.

	expected := '<ol>
<li>foo</li>
<li></li>
<li>bar</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample188 [
	input := '*'.

	expected := '<ul>
<li></li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample189 [
	input := ' 1.  A paragraph
     with two lines.

         indented code

     > A block quote.'.

	expected := '<ol>
<li>
<p>A paragraph
with two lines.</p>
<pre><code>indented code
</code></pre>
<blockquote>
<p>A block quote.</p>
</blockquote>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample190 [
	input := '  1.  A paragraph
      with two lines.

          indented code

      > A block quote.'.

	expected := '<ol>
<li>
<p>A paragraph
with two lines.</p>
<pre><code>indented code
</code></pre>
<blockquote>
<p>A block quote.</p>
</blockquote>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample191 [
	input := '   1.  A paragraph
       with two lines.

           indented code

       > A block quote.'.

	expected := '<ol>
<li>
<p>A paragraph
with two lines.</p>
<pre><code>indented code
</code></pre>
<blockquote>
<p>A block quote.</p>
</blockquote>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample192 [
	input := '    1.  A paragraph
        with two lines.

            indented code

        > A block quote.'.

	expected := '<pre><code>1.  A paragraph
    with two lines.

        indented code

    &gt; A block quote.
</code></pre>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample193 [
	input := '  1.  A paragraph
with two lines.

          indented code

      > A block quote.'.

	expected := '<ol>
<li>
<p>A paragraph
with two lines.</p>
<pre><code>indented code
</code></pre>
<blockquote>
<p>A block quote.</p>
</blockquote>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample194 [
	input := '  1.  A paragraph
    with two lines.'.

	expected := '<ol>
<li>A paragraph
with two lines.</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample195 [
	input := '> 1. > Blockquote
continued here.'.

	expected := '<blockquote>
<ol>
<li>
<blockquote>
<p>Blockquote
continued here.</p>
</blockquote>
</li>
</ol>
</blockquote>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample196 [
	input := '> 1. > Blockquote
> continued here.'.

	expected := '<blockquote>
<ol>
<li>
<blockquote>
<p>Blockquote
continued here.</p>
</blockquote>
</li>
</ol>
</blockquote>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample197 [
	input := '- foo
  - bar
    - baz'.

	expected := '<ul>
<li>foo
<ul>
<li>bar
<ul>
<li>baz</li>
</ul>
</li>
</ul>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample198 [
	input := '- foo
 - bar
  - baz'.

	expected := '<ul>
<li>foo</li>
<li>bar</li>
<li>baz</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample199 [
	input := '10) foo
    - bar'.

	expected := '<ol start="10">
<li>foo
<ul>
<li>bar</li>
</ul>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample200 [
	input := '10) foo
   - bar'.

	expected := '<ol start="10">
<li>foo</li>
</ol>
<ul>
<li>bar</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample201 [
	input := '- - foo'.

	expected := '<ul>
<li>
<ul>
<li>foo</li>
</ul>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample202 [
	input := '1. - 2. foo'.

	expected := '<ol>
<li>
<ul>
<li>
<ol start="2">
<li>foo</li>
</ol>
</li>
</ul>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #'list items' }
PPCommonMarkSpecTest >> testExample203 [
	input := '- # Foo
- Bar
  ---
  baz'.

	expected := '<ul>
<li>
<h1>Foo</h1>
</li>
<li>
<h2>Bar</h2>baz</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample204 [
	input := '- foo
- bar
+ baz'.

	expected := '<ul>
<li>foo</li>
<li>bar</li>
</ul>
<ul>
<li>baz</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample205 [
	input := '1. foo
2. bar
3) baz'.

	expected := '<ol>
<li>foo</li>
<li>bar</li>
</ol>
<ol start="3">
<li>baz</li>
</ol>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample206 [
	input := 'Foo
- bar
- baz'.

	expected := '<p>Foo</p>
<ul>
<li>bar</li>
<li>baz</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample207 [
	input := 'The number of windows in my house is
14.  The number of doors is 6.'.

	expected := '<p>The number of windows in my house is</p>
<ol start="14">
<li>The number of doors is 6.</li>
</ol>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample208 [
	input := '- foo

- bar


- baz'.

	expected := '<ul>
<li>
<p>foo</p>
</li>
<li>
<p>bar</p>
</li>
</ul>
<ul>
<li>baz</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample209 [
	input := '- foo


  bar
- baz'.

	expected := '<ul>
<li>foo</li>
</ul>
<p>bar</p>
<ul>
<li>baz</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample210 [
	input := '- foo
  - bar
    - baz


      bim'.

	expected := '<ul>
<li>foo
<ul>
<li>bar
<ul>
<li>baz</li>
</ul>
</li>
</ul>
</li>
</ul>
<pre><code>  bim
</code></pre>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample211 [
	input := '- foo
- bar


- baz
- bim'.

	expected := '<ul>
<li>foo</li>
<li>bar</li>
</ul>
<ul>
<li>baz</li>
<li>bim</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample212 [
	input := '-   foo

    notcode

-   foo


    code'.

	expected := '<ul>
<li>
<p>foo</p>
<p>notcode</p>
</li>
<li>
<p>foo</p>
</li>
</ul>
<pre><code>code
</code></pre>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample213 [
	input := '- a
 - b
  - c
   - d
  - e
 - f
- g
'.

	expected := '<ul>
<li>a</li>
<li>b</li>
<li>c</li>
<li>d</li>
<li>e</li>
<li>f</li>
<li>g</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample214 [
	input := '- a
- b

- c'.

	expected := '<ul>
<li>
<p>a</p>
</li>
<li>
<p>b</p>
</li>
<li>
<p>c</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample215 [
	input := '* a
*

* c'.

	expected := '<ul>
<li>
<p>a</p>
</li>
<li></li>
<li>
<p>c</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample216 [
	input := '- a
- b

  c
- d'.

	expected := '<ul>
<li>
<p>a</p>
</li>
<li>
<p>b</p>
<p>c</p>
</li>
<li>
<p>d</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample217 [
	input := '

- a
- b

  [ref]: /url
- d'.

	expected := '<ul>
<li>
<p>a</p>
</li>
<li>
<p>b</p>
</li>
<li>
<p>d</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample218 [
	input := '- a
- ```
  b


  ```
- c'.

	expected := '<ul>
<li>a</li>
<li>
<pre><code>b


</code></pre>
</li>
<li>c</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample219 [
	input := '- a
  - b

    c
- d'.

	expected := '<ul>
<li>a
<ul>
<li>
<p>b</p>
<p>c</p>
</li>
</ul>
</li>
<li>d</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample220 [
	input := '* a
  > b
  >
* c'.

	expected := '<ul>
<li>a
<blockquote>
<p>b</p>
</blockquote>
</li>
<li>c</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample221 [
	input := '- a
  > b
  ```
  c
  ```
- d'.

	expected := '<ul>
<li>a
<blockquote>
<p>b</p>
</blockquote>
<pre><code>c
</code></pre>
</li>
<li>d</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample222 [
	input := '- a'.

	expected := '<ul>
<li>a</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample223 [
	input := '- a
  - b'.

	expected := '<ul>
<li>a
<ul>
<li>b</li>
</ul>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample224 [
	input := '1. ```
   foo
   ```

   bar'.

	expected := '<ol>
<li>
<pre><code>foo
</code></pre>
<p>bar</p>
</li>
</ol>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample225 [
	input := '* foo
  * bar

  baz'.

	expected := '<ul>
<li>
<p>foo</p>
<ul>
<li>bar</li>
</ul>
<p>baz</p>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #lists }
PPCommonMarkSpecTest >> testExample226 [
	input := '- a
  - b
  - c

- d
  - e
  - f'.

	expected := '<ul>
<li>
<p>a</p>
<ul>
<li>b</li>
<li>c</li>
</ul>
</li>
<li>
<p>d</p>
<ul>
<li>e</li>
<li>f</li>
</ul>
</li>
</ul>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample227 [
	input := '`hi`lo`'.

	expected := '<p><code>hi</code>lo`</p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample228 [
	input := '\!\"\#\$\%\&\''\(\)\*\+\,\-\.\/\:\;\<\=\>\?\@\[\\\]\^\_\`\{\|\}\~'.

	expected := '<p>!&quot;#$%&amp;''()*+,-./:;&lt;=&gt;?@[\]^_`{|}~</p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample229 [
	input := '\A\a\ \3\φ\«'.

	expected := '<p>\A\a\ \3\φ\«</p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample230 [
	input := '\*not emphasized*
\<br/> not a tag
\[not a link](/foo)
\`not code`
1\. not a list
\* not a list
\# not a header
\[foo]: /url "not a reference"'.

	expected := '<p>*not emphasized*
&lt;br/&gt; not a tag
[not a link](/foo)
`not code`
1. not a list
* not a list
# not a header
[foo]: /url &quot;not a reference&quot;</p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample231 [
	input := '\\*emphasis*'.

	expected := '<p>\<em>emphasis</em></p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample232 [
	input := 'foo\
bar'.

	expected := '<p>foo<br />
bar</p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample233 [
	input := '`` \[\` ``'.

	expected := '<p><code>\[\`</code></p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample234 [
	input := '    \[\]'.

	expected := '<pre><code>\[\]
</code></pre>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample235 [
	input := '~~~
\[\]
~~~'.

	expected := '<pre><code>\[\]
</code></pre>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample236 [
	input := '<http://example.com?find=\*>'.

	expected := '<p><a href="http://example.com?find=%5C*">http://example.com?find=\*</a></p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample237 [
	input := '<a href="/bar\/)">'.

	expected := '<p><a href="/bar\/)"></p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample238 [
	input := '[foo](/bar\* "ti\*tle")'.

	expected := '<p><a href="/bar*" title="ti*tle">foo</a></p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample239 [
	input := '[foo]

[foo]: /bar\* "ti\*tle"'.

	expected := '<p><a href="/bar*" title="ti*tle">foo</a></p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample239a [
	input := '[foo]: /bar\* "ti\*tle"

[foo]'.

	expected := '<p><a href="/bar*" title="ti*tle">foo</a></p>'.

	self assertExample. 
]

{ #category : #'backslash escapes' }
PPCommonMarkSpecTest >> testExample240 [
	input := '``` foo\+bar
foo
```'.

	expected := '<pre><code class="language-foo+bar">foo
</code></pre>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample241 [
	input := '&nbsp; &amp; &copy; &AElig; &Dcaron;'.
	expected := '<p>  &amp; © Æ Ď</p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample242 [
	input := '&#35; &#1234; &#992;'.
	expected := '<p># Ӓ Ϡ</p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample243 [
	input := '&#x22; &#xD06; &#xcab;'.
	expected := '<p>&quot; ആ ಫ</p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample244 [
	input := '&nbsp &x; &#; &#x; &ThisIsWayTooLongToBeAnEntityIsntIt; &hi?;'.

	expected := '<p>&amp;nbsp &amp;x; &amp;#; &amp;#x; &amp;ThisIsWayTooLongToBeAnEntityIsntIt; &amp;hi?;</p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample245 [
	input := '&copy'.

	expected := '<p>&amp;copy</p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample246 [
	input := '&MadeUpEntity;'.

	expected := '<p>&amp;MadeUpEntity;</p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample247 [
	input := '<a href="&ouml;&ouml;.html">'.

	expected := '<p><a href="&ouml;&ouml;.html"></p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample248 [
	input := '[foo](/f&ouml;&ouml; "f&ouml;&ouml;")'.

	expected := '<p><a href="/f%C3%B6%C3%B6" title="föö">foo</a></p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample249 [
	input := '[foo]

[foo]: /f&ouml;&ouml; "f&ouml;&ouml;"'.

	expected := '<p><a href="/f%C3%B6%C3%B6" title="föö">foo</a></p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample249a [
	input := '[foo]: /f&ouml;&ouml; "f&ouml;&ouml;"

[foo]'.

	expected := '<p><a href="/f%C3%B6%C3%B6" title="föö">foo</a></p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample250 [
	input := '``` f&ouml;&ouml;
foo
```'.

	expected := '<pre><code class="language-föö">foo
</code></pre>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample251 [
	input := '`f&ouml;&ouml;`'.

	expected := '<p><code>f&amp;ouml;&amp;ouml;</code></p>'.

	self assertExample. 
]

{ #category : #entitites }
PPCommonMarkSpecTest >> testExample252 [
	input := '    f&ouml;f&ouml;'.

	expected := '<pre><code>f&amp;ouml;f&amp;ouml;
</code></pre>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample253 [
	input := '`foo`'.

	expected := '<p><code>foo</code></p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample254 [
	input := '`` foo ` bar  ``'.

	expected := '<p><code>foo ` bar</code></p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample255 [
	input := '` `` `'.

	expected := '<p><code>``</code></p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample256 [
	input := '``
foo
``'.

	expected := '<p><code>foo</code></p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample257 [
	input := '`foo   bar
  baz`'.

	expected := '<p><code>foo bar baz</code></p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample258 [
	input := '`foo `` bar`'.

	expected := '<p><code>foo `` bar</code></p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample259 [
	input := '`foo\`bar`'.

	expected := '<p><code>foo\</code>bar`</p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample260 [
	input := '*foo`*`'.

	expected := '<p>*foo<code>*</code></p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample261 [
	input := '[not a `link](/foo`)'.

	expected := '<p>[not a <code>link](/foo</code>)</p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample262 [
	input := '`<a href="`">`'.

	expected := '<p><code>&lt;a href=&quot;</code>&quot;&gt;`</p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample263 [
	input := '<a href="`">`'.

	expected := '<p><a href="`">`</p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample264 [

	input := '`<http://foo.bar.`baz>`'.

	expected := '<p><code>&lt;http://foo.bar.</code>baz&gt;`</p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample265 [

	input := '<http://foo.bar.`baz>`'.

	expected := '<p><a href="http://foo.bar.%60baz">http://foo.bar.`baz</a>`</p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample266 [

	input := '```foo``'.

	expected := '<p>```foo``</p>'.

	self assertExample. 
]

{ #category : #'code spans' }
PPCommonMarkSpecTest >> testExample267 [

	input := '`foo'.

	expected := '<p>`foo</p>'.

	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample268 [

	input := '*foo bar*'.

	expected := '<p><em>foo bar</em></p>'.

	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample269 [

	input := 'a * foo bar*'.

	expected := '<p>a * foo bar*</p>'.

	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample270 [

	input := 'a*"foo"*'.

	expected := '<p>a*&quot;foo&quot;*</p>'.

	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample271 [

	input := '* a *'.

	expected := '<p>* a *</p>'.
	
	true ifTrue: [ ^ self flag: 'bad example? this is a list...' ].
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample272 [

	input := 'foo*bar*'.

	expected := '<p>foo<em>bar</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample273 [

	input := '5*6*78'.

	expected := '<p>5<em>6</em>78</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample274 [

	input := '_foo bar_'.

	expected := '<p><em>foo bar</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample275 [

	input := '_ foo bar_'.

	expected := '<p>_ foo bar_</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample276 [

	input := 'a_"foo"_'.

	expected := '<p>a_&quot;foo&quot;_</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample277 [

	input := 'foo_bar_'.

	expected := '<p>foo_bar_</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample278 [

	input := '5_6_78'.

	expected := '<p>5_6_78</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample279 [

	input := 'пристаням_стремятся_'.

	expected := '<p>пристаням_стремятся_</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample280 [

	input := 'aa_"bb"_cc'.

	expected := '<p>aa_&quot;bb&quot;_cc</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample281 [

	input := 'foo-_(bar)_'.

	expected := '<p>foo-<em>(bar)</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample282 [

	input := '_foo*'.

	expected := '<p>_foo*</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample283 [

	input := '*foo bar *'.

	expected := '<p>*foo bar *</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample284 [

	input := '*foo bar
*'.

	expected := '<p>*foo bar</p>
<ul>
<li></li>
</ul>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample285 [

	input := '*(*foo)'.

	expected := '<p>*(*foo)</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample286 [

	input := '*(*foo*)*'.

	expected := '<p><em>(<em>foo</em>)</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample287 [

	input := '*foo*bar'.

	expected := '<p><em>foo</em>bar</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample288 [

	input := '_foo bar _'.

	expected := '<p>_foo bar _</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample289 [

	input := '_(_foo)'.

	expected := '<p>_(_foo)</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample290 [

	input := '_(_foo_)_'.

	expected := '<p><em>(<em>foo</em>)</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample291 [

	input := '_foo_bar'.

	expected := '<p>_foo_bar</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample292 [

	input := '_пристаням_стремятся'.

	expected := '<p>_пристаням_стремятся</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample293 [

	input := '_foo_bar_baz_'.

	expected := '<p><em>foo_bar_baz</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample294 [

	input := '_(bar)_.'.

	expected := '<p><em>(bar)</em>.</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample295 [

	input := '**foo bar**'.

	expected := '<p><strong>foo bar</strong></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample296 [

	input := '** foo bar**'.

	expected := '<p>** foo bar**</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample297 [

	input := 'a**"foo"**'.

	expected := '<p>a**&quot;foo&quot;**</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample298 [

	input := 'foo**bar**'.

	expected := '<p>foo<strong>bar</strong></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample299 [

	input := '__foo bar__'.

	expected := '<p><strong>foo bar</strong></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample300 [

	input := '__ foo bar__'.
	
	expected := '<p>__ foo bar__</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample301 [

	input := '__
foo bar__'.
	
	expected := '<p>__
foo bar__</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample302 [

	input := 'a__"foo"__'.
	
	expected := '<p>a__&quot;foo&quot;__</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample303 [

	input := 'foo__bar__'.
	
	expected := '<p>foo__bar__</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample304 [

	input := '5__6__78'.
	
	expected := '<p>5__6__78</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample305 [

	input := 'пристаням__стремятся__'.
	
	expected := '<p>пристаням__стремятся__</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample306 [

	input := '__foo, __bar__, baz__'.
	
	expected := '<p><strong>foo, <strong>bar</strong>, baz</strong></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample307 [

	input := 'foo-_(bar)_'.
	
	expected := '<p>foo-<em>(bar)</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample308 [

	input := '**foo bar **'.
	
	expected := '<p>**foo bar **</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample309 [

	input := '**(**foo)'.
	
	expected := '<p>**(**foo)</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample310 [

	input := '*(**foo**)*'.
	
	expected := '<p><em>(<strong>foo</strong>)</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample311 [

	input := '**Gomphocarpus (*Gomphocarpus physocarpus*, syn.
*Asclepias physocarpa*)**'.
	
	expected := '<p><strong>Gomphocarpus (<em>Gomphocarpus physocarpus</em>, syn.
<em>Asclepias physocarpa</em>)</strong></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample312 [

	input := '**foo "*bar*" foo**'.
	
	expected := '<p><strong>foo &quot;<em>bar</em>&quot; foo</strong></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample313 [

	input := '**foo**bar'.
	
	expected := '<p><strong>foo</strong>bar</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample314 [
	input := '__foo bar __'.
	
	expected := '<p>__foo bar __</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample315 [
	input := '__(__foo)'.
	
	expected := '<p>__(__foo)</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample316 [
	input := '_(__foo__)_'.
	
	expected := '<p><em>(<strong>foo</strong>)</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample317 [
	input := '__foo__bar'.
	
	expected := '<p>__foo__bar</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample318 [
	input := '__пристаням__стремятся'.
	
	expected := '<p>__пристаням__стремятся</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample319 [
	input := '__foo__bar__baz__'.
	
	expected := '<p><strong>foo__bar__baz</strong></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample320 [
	input := '_(bar)_.'.
	
	expected := '<p><em>(bar)</em>.</p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample321 [
	input := '*foo [bar](/url)*'.
	
	expected := '<p><em>foo <a href="/url">bar</a></em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample322 [
	input := '*foo
bar*'.
	
	expected := '<p><em>foo
bar</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample323 [
	input := '_foo __bar__ baz_'.
	
	expected := '<p><em>foo <strong>bar</strong> baz</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample324 [
	input := '_foo _bar_ baz_'.
	
	expected := '<p><em>foo <em>bar</em> baz</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample325 [
	input := '__foo_ bar_'.
	
	expected := '<p><em><em>foo</em> bar</em></p>'.
	
	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample326 [
	input := '*foo *bar**'.
	
	expected := '<p><em>foo <em>bar</em></em></p>'.
	
	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample327 [
	input := '*foo **bar** baz*'.
	
	expected := '<p><em>foo <strong>bar</strong> baz</em></p>'.
	
	self assertExample. 
]

{ #category : #emphasis }
PPCommonMarkSpecTest >> testExample328 [
	input := '*foo**bar**baz*'.
	
	expected := '<p><em>foo</em><em>bar</em><em>baz</em></p>'.
	
	"JK: inline not yet implemented properly"
	"self assertExample."
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample396 [
	input := '[link](/uri "title")'.

	expected := '<p><a href="/uri" title="title">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample397 [
	input := '[link](/uri)'.

	expected := '<p><a href="/uri">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample398 [
	input := '[link]()'.

	expected := '<p><a href="">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample399 [
	input := '[link](<>)'.

	expected := '<p><a href="">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample400 [
	input := '[link](/my uri)'.

	expected := '<p>[link](/my uri)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample401 [
	input := '[link](</my uri>)'.

	expected := '<p><a href="/my%20uri">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample402 [
	input := '[link](foo
bar)'.

	expected := '<p>[link](foo
bar)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample403 [
	input := '[link](<foo
bar>)'.

	expected := '<p>[link](<foo
bar>)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample404 [
	input := '[link]((foo)and(bar))'.

	expected := '<p><a href="(foo)and(bar)">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample405 [
	input := '[link](foo(and(bar)))'.

	expected := '<p>[link](foo(and(bar)))</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample406 [
	input := '[link](foo(and\(bar\)))'.

	expected := '<p><a href="foo(and(bar))">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample407 [
	input := '[link](<foo(and(bar))>)'.

	expected := '<p><a href="foo(and(bar))">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample408 [
	input := '[link](foo\)\:)'.

	expected := '<p><a href="foo):">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample409 [
	input := '[link](foo%20b&auml;)'.

	expected := '<p><a href="foo%20b%C3%A4">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample410 [
	input := '[link]("title")'.

	expected := '<p><a href="%22title%22">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample411 [
	input := '[link](/url "title")
[link](/url ''title'')
[link](/url (title))'.

	expected := '<p><a href="/url" title="title">link</a>
<a href="/url" title="title">link</a>
<a href="/url" title="title">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample412 [
	input := '[link](/url "title \"&quot;")'.

	expected := '<p><a href="/url" title="title &quot;&quot;">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample413 [
	input := '[link](/url "title "and" title")'.

	expected := '<p>[link](/url &quot;title &quot;and&quot; title&quot;)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample414 [
	input := '[link](/url ''title "and" title'')'.

	expected := '<p><a href="/url" title="title &quot;and&quot; title">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample415 [
	input := '[link](   /uri
  "title"  )'.

	expected := '<p><a href="/uri" title="title">link</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample416 [
	input := '[link] (/uri)'.

	expected := '<p>[link] (/uri)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample417 [
	input := '[link [foo [bar]]](/uri)'.

	expected := '<p><a href="/uri">link [foo [bar]]</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample418 [
	input := '[link] bar](/uri)'.

	expected := '<p>[link] bar](/uri)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample419 [
	input := '[link [bar](/uri)'.

	expected := '<p>[link <a href="/uri">bar</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample420 [
	input := '[link \[bar](/uri)'.

	expected := '<p><a href="/uri">link [bar</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample421 [
	input := '[link *foo **bar** `#`*](/uri)'.

	expected := '<p><a href="/uri">link <em>foo <strong>bar</strong> <code>#</code></em></a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample422 [
	input := '[![moon](moon.jpg)](/uri)'.

	expected := '<p><a href="/uri"><img src="moon.jpg" alt="moon" /></a></p>'.

	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample423 [
	input := '[foo [bar](/uri)](/uri)'.

	expected := '<p>[foo <a href="/uri">bar</a>](/uri)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample424 [
	input := '[foo *[bar [baz](/uri)](/uri)*](/uri)'.

	expected := '<p>[foo <em>[bar <a href="/uri">baz</a>](/uri)</em>](/uri)</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample425 [
	input := '![[[foo](uri1)](uri2)](uri3)'.

	expected := '<p><img src="uri3" alt="[foo](uri2)" /></p>'.

	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample426 [
	input := '*[foo*](/uri)'.

	expected := '<p>*<a href="/uri">foo*</a></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample427 [
	input := '[foo *bar](baz*)'.

	expected := '<p><a href="baz*">foo *bar</a></p>'.

	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample428 [
	input := '*foo [bar* baz]'.

	expected := '<p><em>foo [bar</em> baz]</p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample429 [
	input := '[foo <bar attr="](baz)">'.

	expected := '<p>[foo <bar attr="](baz)"></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample430 [
	input := '[foo`](/uri)`'.

	expected := '<p>[foo<code>](/uri)</code></p>'.
	self assertExample. 
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample431 [
	input := '[foo<http://example.com/?search=](uri)>'.

	expected := '<p>[foo<a href="http://example.com/?search=%5D(uri)">http://example.com/?search=](uri)</a></p>'.

	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample432 [
	input := '[foo][bar]

[bar]: /url "title"'.

	expected := '<p><a href="/url" title="title">foo</a></p>'.

	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #links }
PPCommonMarkSpecTest >> testExample433 [
	input := '[link [foo [bar]]][ref]

[ref]: /uri'.

	expected := '<p><a href="/uri">link [foo [bar]]</a></p>'.

	self flag: 'JK: inline not yet implemented properly'
	"self assertExample."
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample493 [
	input := '<http://foo.bar.baz>'.

	expected := '<p><a href="http://foo.bar.baz">http://foo.bar.baz</a></p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample494 [
	input := '<http://foo.bar.baz/test?q=hello&id=22&boolean>'.

	expected := '<p><a href="http://foo.bar.baz/test?q=hello&amp;id=22&amp;boolean">http://foo.bar.baz/test?q=hello&amp;id=22&amp;boolean</a></p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample495 [
	input := '<irc://foo.bar:2233/baz>'.

	expected := '<p><a href="irc://foo.bar:2233/baz">irc://foo.bar:2233/baz</a></p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample496 [
	input := '<MAILTO:FOO@BAR.BAZ>'.

	expected := '<p><a href="MAILTO:FOO@BAR.BAZ">MAILTO:FOO@BAR.BAZ</a></p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample497 [
	input := '<http://foo.bar/baz bim>'.

	expected := '<p>&lt;http://foo.bar/baz bim&gt;</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample498 [
	input := '<http://example.com/\[\>'.

	expected := '<p><a href="http://example.com/%5C%5B%5C">http://example.com/\[\</a></p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample499 [
	input := '<foo@bar.example.com>'.

	expected := '<p><a href="mailto:foo@bar.example.com">foo@bar.example.com</a></p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample500 [
	input := '<foo+special@Bar.baz-bar0.com>'.

	expected := '<p><a href="mailto:foo+special@Bar.baz-bar0.com">foo+special@Bar.baz-bar0.com</a></p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample501 [
	input := '<foo\+@bar.example.com>'.

	expected := '<p>&lt;foo+@bar.example.com&gt;</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample502 [
	input := '<>'.

	expected := '<p>&lt;&gt;</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample503 [
	input := '<heck://bing.bong>'.

	expected := '<p>&lt;heck://bing.bong&gt;</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample504 [
	input := '< http://foo.bar >'.

	expected := '<p>&lt; http://foo.bar &gt;</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample505 [
	input := '<foo.bar.baz>'.

	expected := '<p>&lt;foo.bar.baz&gt;</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample506 [
	input := '<localhost:5001/foo>'.

	expected := '<p>&lt;localhost:5001/foo&gt;</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample507 [
	input := 'http://example.com'.

	expected := '<p>http://example.com</p>'.

	self assertExample. 
]

{ #category : #autolinks }
PPCommonMarkSpecTest >> testExample508 [
	input := 'foo@bar.example.com'.

	expected := '<p>foo@bar.example.com</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample509 [
	input := '<a><bab><c2c>'.

	expected := '<p><a><bab><c2c></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample510 [
	input := '<a/><b2/>'.

	expected := '<p><a/><b2/></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample511 [
	input := '<a  /><b2
data="foo" >'.

	expected := '<p><a  /><b2
data="foo" ></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample512 [
	input := '<a foo="bar" bam = ''baz <em>"</em>''
_boolean zoop:33=zoop:33 />'.

	expected := '<p><a foo="bar" bam = ''baz <em>"</em>''
_boolean zoop:33=zoop:33 /></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample513 [
	input := '<33> <__>'.

	expected := '<p>&lt;33&gt; &lt;__&gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample514 [
	input := '<a h*#ref="hi">'.

	expected := '<p>&lt;a h*#ref=&quot;hi&quot;&gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample515 [
	input := '<a href="hi''> <a href=hi''>'.

	expected := '<p>&lt;a href=&quot;hi''&gt; &lt;a href=hi''&gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample516 [
	input := '< a><
foo><bar/ >'.

	expected := '<p>&lt; a&gt;&lt;
foo&gt;&lt;bar/ &gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample517 [
	input := '<a href=''bar''title=title>'.

	expected := '<p>&lt;a href=''bar''title=title&gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample518 [
	input := '</a>
</foo >'.

	expected := '<p></a>
</foo ></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample519 [
	input := '</a href="foo">'.

	expected := '<p>&lt;/a href=&quot;foo&quot;&gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample520 [
	input := 'foo <!-- this is a
comment - with hyphen -->'.

	expected := '<p>foo <!-- this is a
comment - with hyphen --></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample521 [
	input := 'foo <!-- not a comment -- two hyphens -->'.

	expected := '<p>foo &lt;!-- not a comment -- two hyphens --&gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample522 [
	input := 'foo <!--> foo -->

foo <!-- foo--->'.

	expected := '<p>foo &lt;!--&gt; foo --&gt;</p>
<p>foo &lt;!-- foo---&gt;</p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample523 [
	input := 'foo <?php echo $a; ?>'.

	expected := '<p>foo <?php echo $a; ?></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample524 [
	input := 'foo <!ELEMENT br EMPTY>'.

	expected := '<p>foo <!ELEMENT br EMPTY></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample525 [
	input := 'foo <![CDATA[>&<]]>'.

	expected := '<p>foo <![CDATA[>&<]]></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample526 [
	input := '<a href="&ouml;">'.

	expected := '<p><a href="&ouml;"></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample527 [
	input := '<a href="&ouml;">'.

	expected := '<p><a href="&ouml;"></p>'.

	self assertExample. 
]

{ #category : #'raw html' }
PPCommonMarkSpecTest >> testExample528 [
	input := '<a href="\"">'.

	expected := '<p>&lt;a href=&quot;&quot;&quot;&gt;</p>'.

	self assertExample. 
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample529 [
	input := 'foo  
baz'.
	expected := '<p>foo<br />
baz</p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample530 [
	input := 'foo\
baz'.
	expected := '<p>foo<br />
baz</p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample531 [
	input := 'foo       
baz'.
	expected := '<p>foo<br />
baz</p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample532 [
	input := 'foo  
     bar'.
	expected := '<p>foo<br />
bar</p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample533 [
	input := 'foo\
     bar'.
	expected := '<p>foo<br />
bar</p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample534 [
	input := '*foo  
bar*'.
	expected := '<p><em>foo<br />
bar</em></p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample535 [
	input := '*foo\
bar*'.
	expected := '<p><em>foo<br />
bar</em></p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample536 [
	input := '`code  
span`'.
	expected := '<p><code>code span</code></p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample537 [
	input := '`code\
span`'.
	expected := '<p><code>code\ span</code></p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample538 [
	input := '<a href="foo  
bar">'.
	expected := '<p><a href="foo  
bar"></p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample539 [
	input := '<a href="foo\
bar">'.
	expected := '<p><a href="foo\
bar"></p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample540 [
	input := 'foo\'.
	expected := '<p>foo\</p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample541 [
	input := 'foo  '.
	expected := '<p>foo</p>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample542 [
	input := '### foo\'.
	expected := '<h3>foo\</h3>'.

	self assertExample.
]

{ #category : #'hard line breaks' }
PPCommonMarkSpecTest >> testExample543 [
	input := '### foo  '.
	expected := '<h3>foo</h3>'.

	self assertExample.
]

{ #category : #'soft line breaks' }
PPCommonMarkSpecTest >> testExample544 [
	input := 'foo
baz'.
	expected := '<p>foo
baz</p>'.

	self assertExample.
]

{ #category : #'soft line breaks' }
PPCommonMarkSpecTest >> testExample545 [
	input := 'foo 
 baz'.
	expected := '<p>foo
baz</p>'.

	self assertExample.
]

{ #category : #'textual content' }
PPCommonMarkSpecTest >> testExample546 [
	input := 'hello $.;''there'.
	expected := '<p>hello $.;''there</p>'.

	self assertExample.
]

{ #category : #'textual content' }
PPCommonMarkSpecTest >> testExample547 [
	input := 'Foo χρῆν'.
	expected := '<p>Foo χρῆν</p>'.

	self assertExample.
]

{ #category : #'textual content' }
PPCommonMarkSpecTest >> testExample548 [
	input := 'Multiple     spaces'.
	expected := '<p>Multiple     spaces</p>'.

	self assertExample.
]

{ #category : #'as yet unclassified' }
PPCommonMarkSpecTest >> testExtra1 [
	input := '# Foo
bar'.

	expected := '<h1>Foo</h1>
<p>bar</p>'.

	self assertExample. 
]

{ #category : #'as yet unclassified' }
PPCommonMarkSpecTest >> testExtra2 [
	input := '- # Foo
  bar'.

	expected := '<ul>
<li>
<h1>Foo</h1>bar</li>
</ul>'.

	self assertExample. 
]

{ #category : #'as yet unclassified' }
PPCommonMarkSpecTest >> testExtra3 [
	input := '*[foo]*'.

	expected := '<p><em>[foo]</em></p>'.

	self assertExample. 
]

{ #category : #'as yet unclassified' }
PPCommonMarkSpecTest >> testExtra4 [
	input := '*[foo)*]'.

	expected := '<p><em>[foo)</em>]</p>'.

	self assertExample. 
]

{ #category : #paragraphs }
PPCommonMarkSpecTest >> testParagraphExtra1 [
	input := '  aaa     
***'.

	expected := '<p>aaa</p>
<hr />'.

	self assertExample. 
]
